package com.dahe.examine.ui.gone

import android.graphics.Color
import android.os.Bundle
import android.text.TextUtils
import android.view.View
import android.widget.TextView
import androidx.core.widget.addTextChangedListener
import androidx.recyclerview.widget.LinearLayoutManager
import com.bigkoo.pickerview.builder.TimePickerBuilder
import com.dahe.dispatch.cuspop.SelectTimePopup
import com.dahe.examine.R
import com.dahe.examine.adapter.GoneAdapter
import com.dahe.examine.base.AppConfig
import com.dahe.examine.bean.ApplyBean
import com.dahe.examine.bean.CountBean
import com.dahe.examine.net.BaseObserver
import com.dahe.examine.net.DataManager
import com.dahe.examine.net.RxHttpCallBack
import com.dahe.examine.ui.gone.activity.NotReportedActivity
import com.dahe.examine.ui.gone.activity.UserDetailActivity
import com.dahe.mylibrary.base.BaseFragment
import com.dahe.mylibrary.callback.RefreshCallBack
import com.dahe.mylibrary.net.CommonResponseBean
import com.dahe.mylibrary.net.PagerBean
import com.dahe.mylibrary.utils.ActivityUtils
import com.dahe.mylibrary.utils.TimeUtil
import com.lxj.xpopup.XPopup
import kotlinx.android.synthetic.main.fragment_gone.*
import kotlinx.android.synthetic.main.fragment_home.recyclerView
import java.text.SimpleDateFormat
import java.util.*


class GoneFragment : BaseFragment(), RefreshCallBack, View.OnClickListener {

    var date: String = TimeUtil.getNowString(SimpleDateFormat("yyyy-MM-dd",
        Locale.getDefault()))

    lateinit var applyAdapter: GoneAdapter

    override fun getContentViewLayoutID() = R.layout.fragment_gone

    override fun onFragmentVisibleChange(isVisible: Boolean) {
        if (isVisible) {
            initData()
        } else {
        }
    }


    override fun onFragmentFirstVisible() {
        setTitleBar("已使用", true,"未报") {
            ActivityUtils.startActivityForResult(requireActivity(),
                NotReportedActivity::class.java,
                1)
        }

        initRec()
        initData()
        tvSearch.setOnClickListener(this)
        llClear.setOnClickListener(this)

        tvSearch.addTextChangedListener {
            if (it.toString().length > 0) {
                llClear.visibility = View.VISIBLE
            } else {
                llClear.visibility = View.GONE
            }
        }
    }

    override fun onClick(v: View) {
        when (v.id) {
            R.id.tvSearch -> setBir(tvSearch)
            R.id.llClear -> {
                tvSearch.text = ""
                date = TimeUtil.getNowString(SimpleDateFormat("yyyy-MM-dd",
                    Locale.getDefault()))
                initData()
            }
        }
    }

    override fun getRefreshDate(stat: Int, page: Int, count: Int) {
    }

    fun initData() {
        DataManager.getInstance().useList(date)
            .compose(DataManager.setThread())
            .subscribe(BaseObserver(mContext, object : RxHttpCallBack<PagerBean<ApplyBean>>() {
                override fun onSuccess(t: CommonResponseBean<PagerBean<ApplyBean>>) {
                    super.onSuccess(t)

                    applyAdapter.setList(t.data.rows)
                }
            }))

        getCount()
    }

    fun getCount() {
        DataManager.getInstance().useCount("",date)
            .compose(DataManager.setThread())
            .subscribe(BaseObserver(mContext, object : RxHttpCallBack<CountBean>() {
                override fun onSuccess(t: CommonResponseBean<CountBean>?) {
                    super.onSuccess(t)
                    tvYf.text = t?.data?.numberOfPasses
                    tvYsy.text = t?.data?.passNoNumber
                    tvYsp.text = t?.data?.notUsedNumber

                    tvMf1.text = t?.data?.numberOfPassesMF
                    tvMf2.text = t?.data?.passNoNumberMF
                    tvMf3.text = t?.data?.notUsedNumberMF
                    tvSf1.text = t?.data?.numberOfPassesSF
                    tvSf2.text = t?.data?.passNoNumberSF
                    tvSf3.text = t?.data?.notUsedNumberSF
                }
            }))
    }

    fun search() {
        XPopup.Builder(mContext)
            .enableDrag(true)
            .hasShadowBg(true)
            .isDestroyOnDismiss(true) //对于只使用一次的弹窗，推荐设置这个
            .asCustom(SelectTimePopup(mContext).setOnMyItemClickListener(object :
                SelectTimePopup.OnMyItemClickListener {
                override fun onItemClick(startTime: String, endTime: String) {
                }
            }))
            .show()
    }

    fun initRec() {
        recyclerView.layoutManager = LinearLayoutManager(mContext,
            LinearLayoutManager.VERTICAL, false)
        recyclerView.setHasFixedSize(true)
        applyAdapter = GoneAdapter(-1)
        recyclerView.adapter = applyAdapter

        applyAdapter.setOnItemClickListener { adapter, view, position ->
            val bundle = Bundle()
            bundle.putSerializable(AppConfig.BEAN, applyAdapter.data[position])
            bundle.putString(AppConfig.TIME,date)
            ActivityUtils.startActivity(mContext, UserDetailActivity::class.java, bundle)
        }
    }

    fun setBir(view: TextView) {
        val startDate = Calendar.getInstance()
        val endtDate = Calendar.getInstance()
        val currDate = Calendar.getInstance()
        startDate[1990, 0] = 1
        endtDate[2100, 0] = 1


        if (!TextUtils.isEmpty(view.getText())) {
            val date = TimeUtil.string2Date(view.getText().toString(),
                SimpleDateFormat("yyyy-MM-dd", Locale.getDefault()))
            if (date != null) currDate.time = date
        }


        val pvTime = TimePickerBuilder(
            context
        ) { date, v -> //选中事件回调
//            TimeUtil.date2String(date,SimpleDateFormat("yyyy-MM-dd", Locale.getDefault()))
            val data =
                TimeUtil.date2String(date, SimpleDateFormat("yyyy-MM-dd", Locale.getDefault()))
            view.text = data
            GoneFragment@ this.date = data
            initData()
        }.setSubmitColor(Color.parseColor("#F1474B")) //确定按钮文字颜色
            .setCancelColor(Color.parseColor("#F1474B")) //取消按钮文字颜色
            .setTitleBgColor(Color.parseColor("#FFFFFF"))
            .setType(booleanArrayOf(true, true, true, false, false, false))
            .setTitleText("选择时间")
            .setDate(currDate)
            .setRangDate(startDate, endtDate)
            .setBgColor(Color.parseColor("#F5F5F5"))
            .build()
        //                 pvTime.setDate(Calendar.getInstance());//注：根据需求来决定是否使用该方法（一般是精确到秒的情况），此项可以在弹出选择器的时候重新设置当前时间，避免在初始化之后由于时间已经设定，导致选中时间与当前时间不匹配的问题。
        pvTime.show()
    }


}